==> apache-atlas-2.3.0-sources.tar.gz: apache-atlas-sources-2.3.0/docs/docz-lib/config/menu.js <==
export default [
    "Overview",
    {
        name: "Documentation",
        menu: [
            {
                name: "Features",
                menu: [
                    "High Level Architecture",
                    "Type System",
                    "Glossary",
                    "Classification Propagation",
                    "Notifications",
                    "High Availability",
                    "Business Metadata"
                ]
            },
            {
                name: "Search",
                menu: [
                    "Basic Search",
                    "Advanced Search"
                ]
            },
            {
                name: "Hooks",
                menu: [
                    "HBase",
                    "Hive",
                    "Sqoop",
                    "Storm",
                    "Kafka",
                    "Falcon"
                ]
            },
            {
                name: "Import/Export",
                menu: [
                    "Import API",
                    "Import API Options",
                    "Import Entity Transforms",
                    "Import Export API",
                    "Export API",
                    "Export HDFS API",
                    "Export Import Audits",
                    "Incremental Export"
                ]
            },
            {
                name: "Security",
                menu: [
                    "Security Details",
                    "Authentication",
                    "Authorization Model",
                    "Atlas Simple Authorizer",
                    "Atlas Ranger Authorizer"
                ]
            },
            {
                name: "Setup",
                menu: [
                    "Quick Start",
                    "Configuration",
                    "Build Instruction",
                    "Installation Instruction"
                ]
            },
            "REST API",
            {
                name: "Tools",
                menu: [
                    "Atlas Repair Index"
                ]
            },
            {
                name: "Misc",
                menu: [
                    "Atlas Server",
                    "Replicated Attributes",
                    "Soft Reference"
                ]
            }
        ]
    },  {
        name: "Downloads",
        menu: [
            "Download",
            {
                name: "Whats New",
                menu: ["WhatsNew-2.2", "WhatsNew-2.1", "WhatsNew-2.0", "WhatsNew-1.0"]
            },
            "Migration"
        ]
    } ,"For Developers",
    {
        name: "Project Info", menu: [
            "Project Information",
            "Mailing Lists",
            "Team List",
            "Issue Tracking",
            "License",
            "Source Repository"
        ]
    },  "ASF" ];

==> apache-atlas-2.4.0-sources.tar.gz: apache-atlas-sources-2.4.0/docs/docz-lib/config/menu.js <==
export default [
    "Overview",
    {
        name: "Documentation",
        menu: [
            {
                name: "Features",
                menu: [
                    "High Level Architecture",
                    "Type System",
                    "Glossary",
                    "Classification Propagation",
                    "Notifications",
                    "High Availability",
                    "Business Metadata"
                ]
            },
            {
                name: "Search",
                menu: [
                    "Basic Search",
                    "Advanced Search"
                ]
            },
            {
                name: "Hooks",
                menu: [
                    "HBase",
                    "Hive",
                    "Sqoop",
                    "Storm",
                    "Kafka",
                    "Falcon"
                ]
            },
            {
                name: "Import/Export",
                menu: [
                    "Import API",
                    "Import API Options",
                    "Import Entity Transforms",
                    "Import Export API",
                    "Export API",
                    "Export HDFS API",
                    "Export Import Audits",
                    "Incremental Export"
                ]
            },
            {
                name: "Security",
                menu: [
                    "Security Details",
                    "Authentication",
                    "Authorization Model",
                    "Atlas Simple Authorizer",
                    "Atlas Ranger Authorizer"
                ]
            },
            {
                name: "Setup",
                menu: [
                    "Quick Start",
                    "Configuration",
                    "Build Instruction",
                    "Installation Instruction"
                ]
            },
            "REST API",
            {
                name: "Tools",
                menu: [
                    "Atlas Repair Index"
                ]
            },
            {
                name: "Misc",
                menu: [
                    "Atlas Server",
                    "Replicated Attributes",
                    "Soft Reference"
                ]
            }
        ]
    },  {
        name: "Downloads",
        menu: [
            "Download",
            {
                name: "Whats New",
                menu: ["WhatsNew-2.3", "WhatsNew-2.2", "WhatsNew-2.1", "WhatsNew-2.0", "WhatsNew-1.0"]
            },
            "Migration"
        ]
    } ,"For Developers",
    {
        name: "Project Info", menu: [
            "Project Information",
            "Mailing Lists",
            "Team List",
            "Issue Tracking",
            "License",
            "Source Repository"
        ]
    },  "ASF" ];
